Module: CemAcpt::CoreExtensions
- Defined in:
- lib/cem_acpt/core_extensions.rb
Overview
This module holds extensions and refinements to Ruby and the Ruby stdlib
Defined Under Namespace
Modules: ExtendedHash
This module holds extensions and refinements to Ruby and the Ruby stdlib
Modules: ExtendedHash