Module: CemAcpt::CoreExtensions::DeepFreeze

Defined in:
lib/cem_acpt/core_extensions.rb

Overview

DeepFreeze recursively freezes all keys and values in a hash Currently unused, but was used at one point and may be useful again

Defined Under Namespace

Modules: Enumerable, Hash, Kernel, OpenStruct