Exception: CemAcpt::Provision::OsData::UnknownOsFamilyError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/cem_acpt/provision/terraform/os_data.rb

Overview

Raised when a test name cannot be classified as either a Linux or Windows test by ‘os_family_for`.