Module: Platform::SpecMethods
- Defined in:
- lib/cem_acpt/platform/gcp.rb
Overview
Holds class methods called from spec tests.
Instance Method Summary collapse
-
#apply_manifest(instance_name, manifest, opts = {}) ⇒ String
Apllies the given Puppet manifest on the given instance.
-
#command_provider ⇒ CemAcpt::Platform::Gcp::Cmd
Returns an instance of the GCP platform class command provider.
-
#run_shell(instance_name, cmd, opts = {}) ⇒ String
Runs a shell command on the given instance.
Instance Method Details
#apply_manifest(instance_name, manifest, opts = {}) ⇒ String
Apllies the given Puppet manifest on the given instance
72 73 74 |
# File 'lib/cem_acpt/platform/gcp.rb', line 72 def apply_manifest(instance_name, manifest, opts = {}) command_provider.apply_manifest(instance_name, manifest, opts) end |
#command_provider ⇒ CemAcpt::Platform::Gcp::Cmd
Returns an instance of the GCP platform class command provider
63 64 65 |
# File 'lib/cem_acpt/platform/gcp.rb', line 63 def command_provider CemAcpt::Platform::Gcp::Cmd.new(out_format: 'json') end |
#run_shell(instance_name, cmd, opts = {}) ⇒ String
Runs a shell command on the given instance
81 82 83 |
# File 'lib/cem_acpt/platform/gcp.rb', line 81 def run_shell(instance_name, cmd, opts = {}) command_provider.run_shell(instance_name, cmd, opts) end |